"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
class AngularJson {
    constructor(tree, options) {
        this.tree = tree;
        this.path = this.getPath();
        this.content = this.getContent();
        this.schema = this.getSchema();
        this.projectName = this.getProjectName(options);
        this.project = this.getProject();
    }
    getPath() {
        const possibleFiles = ['/angular.json', '/.angular.json'];
        const path = possibleFiles.filter(file => this.tree.exists(file))[0];
        return path;
    }
    getContent() {
        const configBuffer = this.tree.read(this.path);
        if (configBuffer === null) {
            throw new schematics_1.SchematicsException(`Could not find angular.json`);
        }
        return configBuffer.toString();
    }
    getSchema() {
        let schema;
        try {
            schema = core_1.parseJson(this.content, core_1.JsonParseMode.Loose);
        }
        catch (e) {
            throw new schematics_1.SchematicsException(`Could not parse angular.json: ` + e.message);
        }
        return schema;
    }
    getProjectName(options) {
        let projectName = options.project;
        if (!projectName) {
            if (this.schema.defaultProject) {
                projectName = this.schema.defaultProject;
            }
            else {
                throw new schematics_1.SchematicsException('No project selected and no default project in the workspace');
            }
        }
        return projectName;
    }
    getProject() {
        const project = this.schema.projects[this.projectName];
        if (!project) {
            throw new schematics_1.SchematicsException('Project is not defined in this workspace');
        }
        if (project.projectType !== 'application') {
            throw new schematics_1.SchematicsException(`Deploy requires a project type of "application" in angular.json`);
        }
        if (!project.architect ||
            !project.architect.build ||
            !project.architect.build.options ||
            !project.architect.build.options.outputPath) {
            throw new schematics_1.SchematicsException(`Cannot read the output path (architect.build.options.outputPath) of project "${this.projectName}" in angular.json`);
        }
        return project;
    }
    addDeployArchitect(config) {
        if (!this.project || !this.project.architect) {
            throw new schematics_1.SchematicsException('An error has occured during modification of angular.json');
        }
        this.project.architect['deploy'] = config;
        this.updateTree();
    }
    updateTree() {
        this.tree.overwrite(this.path, JSON.stringify(this.schema, null, 2));
    }
}
exports.AngularJson = AngularJson;
//# sourceMappingURL=angular-json.js.map